@@ -1,19 +1,13 @@
-use crate::utils::convert_notation_into_position;
 use ruci::{Engine, Go};
 use shakmaty::fen::Fen;
+use shakmaty::uci::UciMove;
 use std::borrow::Cow;
-use std::cell::RefCell;
-use std::io::BufReader;
-use std::process::{Child, ChildStdin, ChildStdout, Command};
-use std::rc::Rc;
+use std::process::Command;
 use std::str::FromStr;
 
 #[derive(Clone)]
 pub struct Bot {
-    // TODO, FIXME: Don't reuse the same process... Chess engines are not meant to be used like this
-    #[allow(dead_code)]
-    process: Rc<RefCell<Child>>,
-    engine: Rc<RefCell<Engine<BufReader<ChildStdout>, ChildStdin>>>,
+    pub engine_path: String,
     /// Used to indicate if a bot move is following
     pub bot_will_move: bool,
     // if the bot is starting, meaning the player is black
@@ -24,27 +18,37 @@ pub struct Bot {
 
 impl Bot {
     pub fn new(engine_path: &str, is_bot_starting: bool, depth: u8) -> Bot {
-        let mut process = Command::new(engine_path)
-            .stdin(std::process::Stdio::piped())
-            .stdout(std::process::Stdio::piped())
-            .spawn()
-            .unwrap();
-
-        let engine = Rc::new(RefCell::new(
-            Engine::from_process(&mut process, false).unwrap(),
-        ));
-
         Self {
-            process: Rc::new(RefCell::new(process)),
-            engine,
+            engine_path: engine_path.to_string(),
             bot_will_move: false,
             is_bot_starting,
             depth,
         }
     }
 
-    pub fn get_move(&self, fen: &str) -> String {
-        let mut engine = self.engine.borrow_mut();
+    pub fn get_move(&self, fen: &str) -> UciMove {
+        // Parse engine_path to support command-line arguments
+        // Split by spaces, treating first part as command and rest as args
+        let parts: Vec<&str> = self.engine_path.split_whitespace().collect();
+        let (command, args) = if parts.is_empty() {
+            (self.engine_path.as_str(), &[] as &[&str])
+        } else {
+            (parts[0], &parts[1..])
+        };
+
+        let mut cmd = Command::new(command);
+        if !args.is_empty() {
+            cmd.args(args);
+        }
+
+        let mut process = cmd
+            .stdin(std::process::Stdio::piped())
+            .stdout(std::process::Stdio::piped())
+            .spawn()
+            .expect("Failed to spawn engine process");
+
+        let mut engine =
+            Engine::from_process(&mut process, false).expect("Failed to initialize engine");
 
         engine
             .send(ruci::Position::Fen {
@@ -53,7 +57,7 @@ impl Bot {
             })
             .unwrap();
 
-        let best_move = engine
+        engine
             .go(
                 &Go {
                     depth: Some(self.depth as usize),
@@ -63,8 +67,7 @@ impl Bot {
             )
             .unwrap()
             .take_normal()
-            .unwrap();
-
-        convert_notation_into_position(&best_move.r#move.to_string())
+            .unwrap()
+            .r#move
     }
 }
