@@ -1,7 +1,7 @@
-pub mod board;
 pub mod bot;
 pub mod coord;
 pub mod game;
 pub mod game_board;
 pub mod opponent;
+pub mod puzzle;
 pub mod ui;
