@@ -6,7 +6,7 @@ import type * as Preset from '@docusaurus/preset-classic';
 
 const config: Config = {
   title: 'Chess TUI',
-  tagline: 'A rusty chess game in your terminal 🦀',
+  tagline: 'Play chess from your terminal 🦀',
   favicon: 'img/favicon.ico',
 
   // Set the production url of your site here
@@ -34,9 +34,12 @@ const config: Config = {
           sidebarPath: './sidebars.ts',
           editUrl:
             'https://github.com/thomas-mauran/chess-tui/',
+          sidebarCollapsible: true,
         },
         blog: {
           showReadingTime: true,
+          blogSidebarCount: 'ALL',
+          blogSidebarTitle: 'Recent posts',
           feedOptions: {
             type: ['rss', 'atom'],
             xslt: true,
